"""Constants for OpenGL.GLE

Automatically generated by the generateraw script, do not edit!
"""

from ctypes import *
from OpenGL import platform, arrays
from OpenGL.constant import Constant
from OpenGL.raw.GL import _types as GL_types
GLvoid = GL_types.GLvoid



GLE_TEXTURE_ENABLE = Constant( 'GLE_TEXTURE_ENABLE', 65536)
GLE_TEXTURE_NORMAL_CYL = Constant( 'GLE_TEXTURE_NORMAL_CYL', 4)
GLE_TEXTURE_NORMAL_FLAT = Constant( 'GLE_TEXTURE_NORMAL_FLAT', 2)
GLE_TEXTURE_NORMAL_MODEL_CYL = Constant( 'GLE_TEXTURE_NORMAL_MODEL_CYL', 10)
GLE_TEXTURE_NORMAL_MODEL_FLAT = Constant( 'GLE_TEXTURE_NORMAL_MODEL_FLAT', 8)
GLE_TEXTURE_NORMAL_MODEL_SPH = Constant( 'GLE_TEXTURE_NORMAL_MODEL_SPH', 12)
GLE_TEXTURE_NORMAL_SPH = Constant( 'GLE_TEXTURE_NORMAL_SPH', 6)
GLE_TEXTURE_STYLE_MASK = Constant( 'GLE_TEXTURE_STYLE_MASK', 255)
GLE_TEXTURE_VERTEX_CYL = Constant( 'GLE_TEXTURE_VERTEX_CYL', 3)
GLE_TEXTURE_VERTEX_FLAT = Constant( 'GLE_TEXTURE_VERTEX_FLAT', 1)
GLE_TEXTURE_VERTEX_MODEL_CYL = Constant( 'GLE_TEXTURE_VERTEX_MODEL_CYL', 9)
GLE_TEXTURE_VERTEX_MODEL_FLAT = Constant( 'GLE_TEXTURE_VERTEX_MODEL_FLAT', 7)
GLE_TEXTURE_VERTEX_MODEL_SPH = Constant( 'GLE_TEXTURE_VERTEX_MODEL_SPH', 11)
GLE_TEXTURE_VERTEX_SPH = Constant( 'GLE_TEXTURE_VERTEX_SPH', 5)
TUBE_CONTOUR_CLOSED = Constant( 'TUBE_CONTOUR_CLOSED', 4096)
TUBE_JN_ANGLE = Constant( 'TUBE_JN_ANGLE', 2)
TUBE_JN_CAP = Constant( 'TUBE_JN_CAP', 16)
TUBE_JN_CUT = Constant( 'TUBE_JN_CUT', 3)
TUBE_JN_MASK = Constant( 'TUBE_JN_MASK', 15)
TUBE_JN_RAW = Constant( 'TUBE_JN_RAW', 1)
TUBE_JN_ROUND = Constant( 'TUBE_JN_ROUND', 4)
TUBE_NORM_EDGE = Constant( 'TUBE_NORM_EDGE', 512)
TUBE_NORM_FACET = Constant( 'TUBE_NORM_FACET', 256)
TUBE_NORM_MASK = Constant( 'TUBE_NORM_MASK', 3840)
TUBE_NORM_PATH_EDGE = Constant( 'TUBE_NORM_PATH_EDGE', 1024)
__GLE_DOUBLE = Constant( '__GLE_DOUBLE', 1)
__all__ = [
    'GLE_TEXTURE_ENABLE',
    'GLE_TEXTURE_NORMAL_CYL',
    'GLE_TEXTURE_NORMAL_FLAT',
    'GLE_TEXTURE_NORMAL_MODEL_CYL',
    'GLE_TEXTURE_NORMAL_MODEL_FLAT',
    'GLE_TEXTURE_NORMAL_MODEL_SPH',
    'GLE_TEXTURE_NORMAL_SPH',
    'GLE_TEXTURE_STYLE_MASK',
    'GLE_TEXTURE_VERTEX_CYL',
    'GLE_TEXTURE_VERTEX_FLAT',
    'GLE_TEXTURE_VERTEX_MODEL_CYL',
    'GLE_TEXTURE_VERTEX_MODEL_FLAT',
    'GLE_TEXTURE_VERTEX_MODEL_SPH',
    'GLE_TEXTURE_VERTEX_SPH',
    'TUBE_CONTOUR_CLOSED',
    'TUBE_JN_ANGLE',
    'TUBE_JN_CAP',
    'TUBE_JN_CUT',
    'TUBE_JN_MASK',
    'TUBE_JN_RAW',
    'TUBE_JN_ROUND',
    'TUBE_NORM_EDGE',
    'TUBE_NORM_FACET',
    'TUBE_NORM_MASK',
    'TUBE_NORM_PATH_EDGE',
    '__GLE_DOUBLE'
]
