'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SGI_color_matrix'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SGI_color_matrix',error_checker=_errors._error_checker)
GL_COLOR_MATRIX_SGI=_C('GL_COLOR_MATRIX_SGI',0x80B1)
GL_COLOR_MATRIX_STACK_DEPTH_SGI=_C('GL_COLOR_MATRIX_STACK_DEPTH_SGI',0x80B2)
GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI=_C('GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI',0x80B3)
GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI=_C('GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI',0x80BB)
GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI=_C('GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI',0x80B7)
GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI=_C('GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI',0x80BA)
GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI=_C('GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI',0x80B6)
GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI=_C('GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI',0x80B9)
GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI=_C('GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI',0x80B5)
GL_POST_COLOR_MATRIX_RED_BIAS_SGI=_C('GL_POST_COLOR_MATRIX_RED_BIAS_SGI',0x80B8)
GL_POST_COLOR_MATRIX_RED_SCALE_SGI=_C('GL_POST_COLOR_MATRIX_RED_SCALE_SGI',0x80B4)

