'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_texture_norm16'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_texture_norm16',error_checker=_errors._error_checker)
GL_R16_EXT=_C('GL_R16_EXT',0x822A)
GL_R16_SNORM_EXT=_C('GL_R16_SNORM_EXT',0x8F98)
GL_RG16_EXT=_C('GL_RG16_EXT',0x822C)
GL_RG16_SNORM_EXT=_C('GL_RG16_SNORM_EXT',0x8F99)
GL_RGB16_EXT=_C('GL_RGB16_EXT',0x8054)
GL_RGB16_SNORM_EXT=_C('GL_RGB16_SNORM_EXT',0x8F9A)
GL_RGBA16_EXT=_C('GL_RGBA16_EXT',0x805B)
GL_RGBA16_SNORM_EXT=_C('GL_RGBA16_SNORM_EXT',0x8F9B)

