'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_texture_rg'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_texture_rg',error_checker=_errors._error_checker)
GL_R16=_C('GL_R16',0x822A)
GL_R16F=_C('GL_R16F',0x822D)
GL_R16I=_C('GL_R16I',0x8233)
GL_R16UI=_C('GL_R16UI',0x8234)
GL_R32F=_C('GL_R32F',0x822E)
GL_R32I=_C('GL_R32I',0x8235)
GL_R32UI=_C('GL_R32UI',0x8236)
GL_R8=_C('GL_R8',0x8229)
GL_R8I=_C('GL_R8I',0x8231)
GL_R8UI=_C('GL_R8UI',0x8232)
GL_RG=_C('GL_RG',0x8227)
GL_RG16=_C('GL_RG16',0x822C)
GL_RG16F=_C('GL_RG16F',0x822F)
GL_RG16I=_C('GL_RG16I',0x8239)
GL_RG16UI=_C('GL_RG16UI',0x823A)
GL_RG32F=_C('GL_RG32F',0x8230)
GL_RG32I=_C('GL_RG32I',0x823B)
GL_RG32UI=_C('GL_RG32UI',0x823C)
GL_RG8=_C('GL_RG8',0x822B)
GL_RG8I=_C('GL_RG8I',0x8237)
GL_RG8UI=_C('GL_RG8UI',0x8238)
GL_RG_INTEGER=_C('GL_RG_INTEGER',0x8228)

