'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_color_buffer_float'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_color_buffer_float',error_checker=_errors._error_checker)
GL_CLAMP_FRAGMENT_COLOR_ARB=_C('GL_CLAMP_FRAGMENT_COLOR_ARB',0x891B)
GL_CLAMP_READ_COLOR_ARB=_C('GL_CLAMP_READ_COLOR_ARB',0x891C)
GL_CLAMP_VERTEX_COLOR_ARB=_C('GL_CLAMP_VERTEX_COLOR_ARB',0x891A)
GL_FIXED_ONLY_ARB=_C('GL_FIXED_ONLY_ARB',0x891D)
GL_RGBA_FLOAT_MODE_ARB=_C('GL_RGBA_FLOAT_MODE_ARB',0x8820)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glClampColorARB(target,clamp):pass
