'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_OES_texture_buffer'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_OES_texture_buffer',error_checker=_errors._error_checker)
GL_IMAGE_BUFFER_OES=_C('GL_IMAGE_BUFFER_OES',0x9051)
GL_INT_IMAGE_BUFFER_OES=_C('GL_INT_IMAGE_BUFFER_OES',0x905C)
GL_INT_SAMPLER_BUFFER_OES=_C('GL_INT_SAMPLER_BUFFER_OES',0x8DD0)
GL_MAX_TEXTURE_BUFFER_SIZE_OES=_C('GL_MAX_TEXTURE_BUFFER_SIZE_OES',0x8C2B)
GL_SAMPLER_BUFFER_OES=_C('GL_SAMPLER_BUFFER_OES',0x8DC2)
GL_TEXTURE_BINDING_BUFFER_OES=_C('GL_TEXTURE_BINDING_BUFFER_OES',0x8C2C)
GL_TEXTURE_BUFFER_BINDING_OES=_C('GL_TEXTURE_BUFFER_BINDING_OES',0x8C2A)
GL_TEXTURE_BUFFER_DATA_STORE_BINDING_OES=_C('GL_TEXTURE_BUFFER_DATA_STORE_BINDING_OES',0x8C2D)
GL_TEXTURE_BUFFER_OES=_C('GL_TEXTURE_BUFFER_OES',0x8C2A)
GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT_OES=_C('GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT_OES',0x919F)
GL_TEXTURE_BUFFER_OFFSET_OES=_C('GL_TEXTURE_BUFFER_OFFSET_OES',0x919D)
GL_TEXTURE_BUFFER_SIZE_OES=_C('GL_TEXTURE_BUFFER_SIZE_OES',0x919E)
GL_UNSIGNED_INT_IMAGE_BUFFER_OES=_C('GL_UNSIGNED_INT_IMAGE_BUFFER_OES',0x9067)
GL_UNSIGNED_INT_SAMPLER_BUFFER_OES=_C('GL_UNSIGNED_INT_SAMPLER_BUFFER_OES',0x8DD8)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint)
def glTexBufferOES(target,internalformat,buffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLintptr,_cs.GLsizeiptr)
def glTexBufferRangeOES(target,internalformat,buffer,offset,size):pass
