'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_texture_sRGB'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_texture_sRGB',error_checker=_errors._error_checker)
GL_COMPRESSED_SLUMINANCE_ALPHA_EXT=_C('GL_COMPRESSED_SLUMINANCE_ALPHA_EXT',0x8C4B)
GL_COMPRESSED_SLUMINANCE_EXT=_C('GL_COMPRESSED_SLUMINANCE_EXT',0x8C4A)
GL_COMPRESSED_SRGB_ALPHA_EXT=_C('GL_COMPRESSED_SRGB_ALPHA_EXT',0x8C49)
GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_EXT=_C('GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_EXT',0x8C4D)
GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_EXT=_C('GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_EXT',0x8C4E)
GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_EXT=_C('GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_EXT',0x8C4F)
GL_COMPRESSED_SRGB_EXT=_C('GL_COMPRESSED_SRGB_EXT',0x8C48)
GL_COMPRESSED_SRGB_S3TC_DXT1_EXT=_C('GL_COMPRESSED_SRGB_S3TC_DXT1_EXT',0x8C4C)
GL_SLUMINANCE8_ALPHA8_EXT=_C('GL_SLUMINANCE8_ALPHA8_EXT',0x8C45)
GL_SLUMINANCE8_EXT=_C('GL_SLUMINANCE8_EXT',0x8C47)
GL_SLUMINANCE_ALPHA_EXT=_C('GL_SLUMINANCE_ALPHA_EXT',0x8C44)
GL_SLUMINANCE_EXT=_C('GL_SLUMINANCE_EXT',0x8C46)
GL_SRGB8_ALPHA8_EXT=_C('GL_SRGB8_ALPHA8_EXT',0x8C43)
GL_SRGB8_EXT=_C('GL_SRGB8_EXT',0x8C41)
GL_SRGB_ALPHA_EXT=_C('GL_SRGB_ALPHA_EXT',0x8C42)
GL_SRGB_EXT=_C('GL_SRGB_EXT',0x8C40)

