'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_texture_shader'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_texture_shader',error_checker=_errors._error_checker)
GL_CONST_EYE_NV=_C('GL_CONST_EYE_NV',0x86E5)
GL_CULL_FRAGMENT_NV=_C('GL_CULL_FRAGMENT_NV',0x86E7)
GL_CULL_MODES_NV=_C('GL_CULL_MODES_NV',0x86E0)
GL_DEPENDENT_AR_TEXTURE_2D_NV=_C('GL_DEPENDENT_AR_TEXTURE_2D_NV',0x86E9)
GL_DEPENDENT_GB_TEXTURE_2D_NV=_C('GL_DEPENDENT_GB_TEXTURE_2D_NV',0x86EA)
GL_DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV=_C('GL_DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV',0x86F3)
GL_DOT_PRODUCT_DEPTH_REPLACE_NV=_C('GL_DOT_PRODUCT_DEPTH_REPLACE_NV',0x86ED)
GL_DOT_PRODUCT_DIFFUSE_CUBE_MAP_NV=_C('GL_DOT_PRODUCT_DIFFUSE_CUBE_MAP_NV',0x86F1)
GL_DOT_PRODUCT_NV=_C('GL_DOT_PRODUCT_NV',0x86EC)
GL_DOT_PRODUCT_REFLECT_CUBE_MAP_NV=_C('GL_DOT_PRODUCT_REFLECT_CUBE_MAP_NV',0x86F2)
GL_DOT_PRODUCT_TEXTURE_2D_NV=_C('GL_DOT_PRODUCT_TEXTURE_2D_NV',0x86EE)
GL_DOT_PRODUCT_TEXTURE_CUBE_MAP_NV=_C('GL_DOT_PRODUCT_TEXTURE_CUBE_MAP_NV',0x86F0)
GL_DOT_PRODUCT_TEXTURE_RECTANGLE_NV=_C('GL_DOT_PRODUCT_TEXTURE_RECTANGLE_NV',0x864E)
GL_DSDT8_MAG8_INTENSITY8_NV=_C('GL_DSDT8_MAG8_INTENSITY8_NV',0x870B)
GL_DSDT8_MAG8_NV=_C('GL_DSDT8_MAG8_NV',0x870A)
GL_DSDT8_NV=_C('GL_DSDT8_NV',0x8709)
GL_DSDT_MAG_INTENSITY_NV=_C('GL_DSDT_MAG_INTENSITY_NV',0x86DC)
GL_DSDT_MAG_NV=_C('GL_DSDT_MAG_NV',0x86F6)
GL_DSDT_MAG_VIB_NV=_C('GL_DSDT_MAG_VIB_NV',0x86F7)
GL_DSDT_NV=_C('GL_DSDT_NV',0x86F5)
GL_DS_BIAS_NV=_C('GL_DS_BIAS_NV',0x8716)
GL_DS_SCALE_NV=_C('GL_DS_SCALE_NV',0x8710)
GL_DT_BIAS_NV=_C('GL_DT_BIAS_NV',0x8717)
GL_DT_SCALE_NV=_C('GL_DT_SCALE_NV',0x8711)
GL_HILO16_NV=_C('GL_HILO16_NV',0x86F8)
GL_HILO_NV=_C('GL_HILO_NV',0x86F4)
GL_HI_BIAS_NV=_C('GL_HI_BIAS_NV',0x8714)
GL_HI_SCALE_NV=_C('GL_HI_SCALE_NV',0x870E)
GL_LO_BIAS_NV=_C('GL_LO_BIAS_NV',0x8715)
GL_LO_SCALE_NV=_C('GL_LO_SCALE_NV',0x870F)
GL_MAGNITUDE_BIAS_NV=_C('GL_MAGNITUDE_BIAS_NV',0x8718)
GL_MAGNITUDE_SCALE_NV=_C('GL_MAGNITUDE_SCALE_NV',0x8712)
GL_OFFSET_TEXTURE_2D_BIAS_NV=_C('GL_OFFSET_TEXTURE_2D_BIAS_NV',0x86E3)
GL_OFFSET_TEXTURE_2D_MATRIX_NV=_C('GL_OFFSET_TEXTURE_2D_MATRIX_NV',0x86E1)
GL_OFFSET_TEXTURE_2D_NV=_C('GL_OFFSET_TEXTURE_2D_NV',0x86E8)
GL_OFFSET_TEXTURE_2D_SCALE_NV=_C('GL_OFFSET_TEXTURE_2D_SCALE_NV',0x86E2)
GL_OFFSET_TEXTURE_BIAS_NV=_C('GL_OFFSET_TEXTURE_BIAS_NV',0x86E3)
GL_OFFSET_TEXTURE_MATRIX_NV=_C('GL_OFFSET_TEXTURE_MATRIX_NV',0x86E1)
GL_OFFSET_TEXTURE_RECTANGLE_NV=_C('GL_OFFSET_TEXTURE_RECTANGLE_NV',0x864C)
GL_OFFSET_TEXTURE_RECTANGLE_SCALE_NV=_C('GL_OFFSET_TEXTURE_RECTANGLE_SCALE_NV',0x864D)
GL_OFFSET_TEXTURE_SCALE_NV=_C('GL_OFFSET_TEXTURE_SCALE_NV',0x86E2)
GL_PASS_THROUGH_NV=_C('GL_PASS_THROUGH_NV',0x86E6)
GL_PREVIOUS_TEXTURE_INPUT_NV=_C('GL_PREVIOUS_TEXTURE_INPUT_NV',0x86E4)
GL_RGBA_UNSIGNED_DOT_PRODUCT_MAPPING_NV=_C('GL_RGBA_UNSIGNED_DOT_PRODUCT_MAPPING_NV',0x86D9)
GL_SHADER_CONSISTENT_NV=_C('GL_SHADER_CONSISTENT_NV',0x86DD)
GL_SHADER_OPERATION_NV=_C('GL_SHADER_OPERATION_NV',0x86DF)
GL_SIGNED_ALPHA8_NV=_C('GL_SIGNED_ALPHA8_NV',0x8706)
GL_SIGNED_ALPHA_NV=_C('GL_SIGNED_ALPHA_NV',0x8705)
GL_SIGNED_HILO16_NV=_C('GL_SIGNED_HILO16_NV',0x86FA)
GL_SIGNED_HILO_NV=_C('GL_SIGNED_HILO_NV',0x86F9)
GL_SIGNED_INTENSITY8_NV=_C('GL_SIGNED_INTENSITY8_NV',0x8708)
GL_SIGNED_INTENSITY_NV=_C('GL_SIGNED_INTENSITY_NV',0x8707)
GL_SIGNED_LUMINANCE8_ALPHA8_NV=_C('GL_SIGNED_LUMINANCE8_ALPHA8_NV',0x8704)
GL_SIGNED_LUMINANCE8_NV=_C('GL_SIGNED_LUMINANCE8_NV',0x8702)
GL_SIGNED_LUMINANCE_ALPHA_NV=_C('GL_SIGNED_LUMINANCE_ALPHA_NV',0x8703)
GL_SIGNED_LUMINANCE_NV=_C('GL_SIGNED_LUMINANCE_NV',0x8701)
GL_SIGNED_RGB8_NV=_C('GL_SIGNED_RGB8_NV',0x86FF)
GL_SIGNED_RGB8_UNSIGNED_ALPHA8_NV=_C('GL_SIGNED_RGB8_UNSIGNED_ALPHA8_NV',0x870D)
GL_SIGNED_RGBA8_NV=_C('GL_SIGNED_RGBA8_NV',0x86FC)
GL_SIGNED_RGBA_NV=_C('GL_SIGNED_RGBA_NV',0x86FB)
GL_SIGNED_RGB_NV=_C('GL_SIGNED_RGB_NV',0x86FE)
GL_SIGNED_RGB_UNSIGNED_ALPHA_NV=_C('GL_SIGNED_RGB_UNSIGNED_ALPHA_NV',0x870C)
GL_TEXTURE_BORDER_VALUES_NV=_C('GL_TEXTURE_BORDER_VALUES_NV',0x871A)
GL_TEXTURE_DS_SIZE_NV=_C('GL_TEXTURE_DS_SIZE_NV',0x871D)
GL_TEXTURE_DT_SIZE_NV=_C('GL_TEXTURE_DT_SIZE_NV',0x871E)
GL_TEXTURE_HI_SIZE_NV=_C('GL_TEXTURE_HI_SIZE_NV',0x871B)
GL_TEXTURE_LO_SIZE_NV=_C('GL_TEXTURE_LO_SIZE_NV',0x871C)
GL_TEXTURE_MAG_SIZE_NV=_C('GL_TEXTURE_MAG_SIZE_NV',0x871F)
GL_TEXTURE_SHADER_NV=_C('GL_TEXTURE_SHADER_NV',0x86DE)
GL_UNSIGNED_INT_8_8_S8_S8_REV_NV=_C('GL_UNSIGNED_INT_8_8_S8_S8_REV_NV',0x86DB)
GL_UNSIGNED_INT_S8_S8_8_8_NV=_C('GL_UNSIGNED_INT_S8_S8_8_8_NV',0x86DA)
GL_VIBRANCE_BIAS_NV=_C('GL_VIBRANCE_BIAS_NV',0x8719)
GL_VIBRANCE_SCALE_NV=_C('GL_VIBRANCE_SCALE_NV',0x8713)

