'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_compiled_vertex_array'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_compiled_vertex_array',error_checker=_errors._error_checker)
GL_ARRAY_ELEMENT_LOCK_COUNT_EXT=_C('GL_ARRAY_ELEMENT_LOCK_COUNT_EXT',0x81A9)
GL_ARRAY_ELEMENT_LOCK_FIRST_EXT=_C('GL_ARRAY_ELEMENT_LOCK_FIRST_EXT',0x81A8)
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei)
def glLockArraysEXT(first,count):pass
@_f
@_p.types(None,)
def glUnlockArraysEXT():pass
